import { makeStyles } from "@material-ui/core";
import { FC, useEffect, useRef } from "react";
import { useAuth } from "./auth.provider";
const useStyles = makeStyles({
  iframe: {
    height: "300px",
    width: "500px",
    position: "absolute",
    top: "100px",
    left: "50%",
    transform: "translateX(-50%)",
  },
});

export const Login: FC = () => {
  const iframeRef = useRef<HTMLIFrameElement>(null);
  const { login } = useAuth();
  useEffect(() => {
    const iframe = iframeRef.current;
    if (!iframe) {
      return;
    }
    let messagePort: MessagePort;
    const onLoad = (ev: MessageEvent) => {
      if (ev.data !== "init-channel") {
        return;
      }
      messagePort = ev.ports?.[0] as MessagePort;
      messagePort.onmessage = (ev: MessageEvent) => {
        if (ev.data?.type === "logged") {
          login(ev.data.payload);
        }
      };
    };
    window.addEventListener("message", onLoad);

    return () => {
      window.removeEventListener("message", onLoad);
    };
  }, [login]);

  const classes = useStyles();
  return (
    <iframe
      ref={iframeRef}
      className={classes.iframe}
      title="Auth"
      src="http://user.localhost/auth/login"
    ></iframe>
  );
};
